<?php
/**
 * webpage.class.php provides access to our templates
 *
 * It defines a class, templates, which gives access to our boilerplate templates which we 
 * re-use on every page.
 * 
 * @author David Argles <d.argles@gmx.com>
 * @version 22-10-2015, 10:48h
 * @copyright 2015 Haven Consulting
 */

  /**
   * webpage provides access to our templates
   *
   * Besides allowing us to load a particular template, it also allows us to change 
   * parameters in the file.
   * 
   */
  class webpage
  {
    /**
     * @access protected
     * @var class
     */
    protected $heading = "Default Website Heading";
    protected $tagline = "Default website description";
    protected $footer = "Default footer";
    protected $menu = array ("Page 1"=>"page1.php", "Page 2"=>"page2.php");
	
    public function __construct()
    {
      if(@parse_ini_file("library/webpage.ini",true))
      {
        $iniFile = (object) parse_ini_file("webpage.ini",true);
        $this->heading = $iniFile->heading;
        $this->tagline = $iniFile->tagline;
        $this->footer = $iniFile->footer;
        $this->menu = (object) $iniFile->menu;
      }
      return;
    }
	     
    /**
     * render() allows us to change the css file used for a particular page
     * 
     * @param text filename (minus extension)
     * @param array update information in [tag] => [value] format
     * @return The updated template text
     */
    public function render($file, $substitutions = array()) 
  	{
      // Check that the template exists
      $filename = "library/$file.html";
      if(file_exists($filename))
      {
	      // Load the template
	      $template = file_get_contents($filename);
        // Insert simple values from ini file into the substitions list 
	      $substitutions = $substitutions + array("heading" => $this->heading, "tagline" => $this->tagline, 
	        "footer" => $this->footer);
	      // Now add the menu entries from the ini file
	      $menu = "\n";
	      foreach($this->menu as $name => $page)$menu = $menu."      <a href=\"$page\">$name</a>\n";
        $substitutions = $substitutions + array("menu" => $menu);
	      // Substitute any placeholders
	      foreach($substitutions as $key => $replacement) $template = str_replace('{{'.$key.'}}', $replacement, $template); 
      }
      // Send back the result
      return $template;
    }
  }
/**---------------------------------------------
 *             End of Code
 *----------------------------------------------
 */
?>
